History
=======

0.7 - 2013-05-21
----------------

- fixed the TypeError on empty stats - #19
- catch the dns error and display it nicely
- added SSL support - #17
- added clean error display - #16

No notes on earlier releases.
